#ifndef OPTION_ASDL_H
#define OPTION_ASDL_H

namespace option_asdl {

#define ASDL_NAMES struct
ASDL_NAMES option_i {
  enum no_name {
  errexit = 1,
  nounset = 2,
  pipefail = 3,
  inherit_errexit = 4,
  nullglob = 5,
  verbose_errexit = 6,
  verbose_warn = 7,
  noexec = 8,
  xtrace = 9,
  verbose = 10,
  noglob = 11,
  noclobber = 12,
  errtrace = 13,
  posix = 14,
  vi = 15,
  emacs = 16,
  interactive = 17,
  hashall = 18,
  lastpipe = 19,
  failglob = 20,
  extglob = 21,
  nocasematch = 22,
  dotglob = 23,
  extdebug = 24,
  eval_unsafe_arith = 25,
  ignore_flags_not_impl = 26,
  ignore_shopt_not_impl = 27,
  rewrite_extern = 28,
  _allow_command_sub = 29,
  _allow_process_sub = 30,
  dynamic_scope = 31,
  redefine_const = 32,
  redefine_source = 33,
  _running_trap = 34,
  _running_hay = 35,
  _no_debug_trap = 36,
  _no_err_trap = 37,
  strict_parse_equals = 38,
  strict_parse_slice = 39,
  strict_argv = 40,
  strict_arith = 41,
  strict_array = 42,
  strict_control_flow = 43,
  strict_env_binding = 44,
  strict_errexit = 45,
  strict_nameref = 46,
  strict_word_eval = 47,
  strict_tilde = 48,
  strict_glob = 49,
  parse_at = 50,
  parse_proc = 51,
  parse_func = 52,
  parse_brace = 53,
  parse_bracket = 54,
  parse_equals = 55,
  parse_paren = 56,
  parse_ysh_string = 57,
  parse_triple_quote = 58,
  simple_word_eval = 59,
  no_dash_glob = 60,
  command_sub_errexit = 61,
  process_sub_fail = 62,
  xtrace_rich = 63,
  no_xtrace_osh = 64,
  sigpipe_status_ok = 65,
  env_obj = 66,
  init_ysh_globals = 67,
  for_loop_frames = 68,
  parse_at_all = 69,
  no_parse_backslash = 70,
  no_parse_backticks = 71,
  no_parse_bare_word = 72,
  no_parse_dbracket = 73,
  no_parse_dollar = 74,
  no_parse_dparen = 75,
  no_parse_ignored = 76,
  no_parse_osh = 77,
  no_parse_sh_arith = 78,
  no_parse_word_join = 79,
  no_exported = 80,
  no_init_globals = 81,
  no_osh_builtins = 82,
  simple_echo = 83,
  simple_eval_builtin = 84,
  simple_test_builtin = 85,
  expand_aliases = 86,
  progcomp = 87,
  hostcomplete = 88,
  histappend = 89,
  cmdhist = 90,
  assoc_expand_once = 91,
  autocd = 92,
  cdable_vars = 93,
  cdspell = 94,
  checkhash = 95,
  checkjobs = 96,
  checkwinsize = 97,
  complete_fullquote = 98,
  direxpand = 99,
  dirspell = 100,
  execfail = 101,
  extquote = 102,
  force_fignore = 103,
  globasciiranges = 104,
  globstar = 105,
  gnu_errfmt = 106,
  histreedit = 107,
  histverify = 108,
  huponexit = 109,
  interactive_comments = 110,
  lithist = 111,
  localvar_inherit = 112,
  localvar_unset = 113,
  login_shell = 114,
  mailwarn = 115,
  no_empty_cmd_completion = 116,
  nocaseglob = 117,
  progcomp_alias = 118,
  promptvars = 119,
  restricted_shell = 120,
  shift_verbose = 121,
  sourcepath = 122,
  xpg_echo = 123,
  ARRAY_SIZE = 124,
  };
};

typedef int option_t;

ASDL_NAMES builtin_i {
  enum no_name {
  colon = 1,
  dot = 2,
  exec_ = 3,
  eval = 4,
  set = 5,
  shift = 6,
  times = 7,
  trap = 8,
  unset = 9,
  readonly = 10,
  local = 11,
  declare = 12,
  typeset = 13,
  export_ = 14,
  true_ = 15,
  false_ = 16,
  try_ = 17,
  assert_ = 18,
  break_ = 19,
  continue_ = 20,
  return_ = 21,
  exit = 22,
  read = 23,
  echo = 24,
  printf = 25,
  mapfile = 26,
  readarray = 27,
  cd = 28,
  chdir = 29,
  pushd = 30,
  popd = 31,
  dirs = 32,
  pwd = 33,
  source = 34,
  umask = 35,
  ulimit = 36,
  wait = 37,
  jobs = 38,
  fg = 39,
  bg = 40,
  shopt = 41,
  complete = 42,
  compgen = 43,
  compopt = 44,
  compadjust = 45,
  compexport = 46,
  getopts = 47,
  builtin = 48,
  command = 49,
  type = 50,
  hash = 51,
  help = 52,
  history = 53,
  fc = 54,
  alias = 55,
  unalias = 56,
  bind = 57,
  append = 58,
  write = 59,
  json = 60,
  json8 = 61,
  pp = 62,
  hay = 63,
  haynode = 64,
  use = 65,
  error = 66,
  failed = 67,
  fork = 68,
  forkwait = 69,
  redir = 70,
  fopen = 71,
  shvar = 72,
  ctx = 73,
  invoke = 74,
  runproc = 75,
  boolstatus = 76,
  test = 77,
  bracket = 78,
  push_registers = 79,
  source_guard = 80,
  is_main = 81,
  cat = 82,
  rm = 83,
  sleep = 84,
  ARRAY_SIZE = 85,
  };
};

typedef int builtin_t;


}  // namespace option_asdl

#endif  // OPTION_ASDL_H
